Module logging

Module logging 

Logging APIs

Re-exports

pub use witchcraft_logging_api as api;

Modules

mdc
MDC keys managed by Witchcraft.

Functions

audit_log
Write the provided v3 audit log entry to the audit log using the global audit logger.
audit_log_blocking
Blocking variant of audit_log.
event_log
Writes the provided V2 event log entry using the standard logging appender without blocking.