Logging APIs
Re-exports
pub use witchcraft_logging_api as api;
Modules
- mdc
- MDC keys managed by Witchcraft.
Functions
- audit_
log - Write the provided v3 audit log entry to the audit log using the global audit logger.
- audit_
log_ blocking - Blocking variant of audit_log.
- event_
log - Writes the provided V2 event log entry using the standard logging appender without blocking.