pub fn event_log(entry: EventLogV2)Expand description
Writes the provided V2 event log entry using the standard logging appender without blocking.
If the logging appender is not initialized, this instead writes out to stdout.
pub fn event_log(entry: EventLogV2)Writes the provided V2 event log entry using the standard logging appender without blocking.
If the logging appender is not initialized, this instead writes out to stdout.